==> react-build-cli-0.0.15.tgz: package/src/utils.ts <==
import {TransformOptions} from '@babel/core';
import chalk from 'chalk';
import {Configuration as webpackDevServerConfiguration} from 'webpack-dev-server';
import webpack from 'webpack';

interface Configuration extends webpack.Configuration {
    devServer?: webpackDevServerConfiguration;
}

function noop() {
    return null;
}

function getEnv(){
    return process.env.NODE_ENV as 'development' | 'production' ;
}

function isDev() {
    return process.env.NODE_ENV === 'development';
}

function isProduction() {
    return process.env.NODE_ENV === 'production';
}

function isFunction(func: any): boolean {
    return Object.prototype.toString.call(func) === '[object Function]';
}

function isObject(obj: any): boolean {
    return Object.prototype.toString.call(obj) === '[object Object]';
}

function isString(str: any) {
    return Object.prototype.toString.call(str) === '[object String]';
}

function loggerPrefix(message: string, options?: {name?: string}) {
    const {name = 'info'} = options || {};
    console.log(`${chalk.blue(`react-build-cli:${name}`)} ${message}`);
}

function success(info: string) {
    loggerPrefix(`${chalk.green('✔')} ${chalk.blue(info)}`);
}

function logger(info: string) {
    loggerPrefix(chalk.green(info));
}

function warning(info: string) {
    loggerPrefix(chalk.yellow(info));
}

function error(info: string) {
    loggerPrefix(chalk.red(info));
}

function requireModule(modulePath: string) {
    return require(modulePath).default || require(modulePath);
}

function getWebpackProxyPath(webpackConfig: Configuration): string[] {
    if (webpackConfig && webpackConfig.devServer && isObject(webpackConfig.devServer.proxy)) {
        const proxyPath: string[] = Object.keys(webpackConfig.devServer?.proxy || {});
        const resultMapStrings: string[] = [];
        
        proxyPath.forEach(key => {
            const proxy = ((webpackConfig.devServer?.proxy || {}) as any)[key];
            if (isObject(proxy)) {
                resultMapStrings.push(`${key} => ${proxy.target}`);
            }
            else if (isString(proxy)) {
                resultMapStrings.push(`${key} => ${proxy}`);
            }
        });

        return resultMapStrings;
    }

    if (webpackConfig && webpackConfig.devServer && Array.isArray(webpackConfig.devServer.proxy)) {
        return (webpackConfig.devServer?.proxy || []).reduce((resultMapStrings: string[], proxy) => {
            if(Array.isArray(proxy.path)) {
                resultMapStrings = [...resultMapStrings, ...proxy.path];
            }
            else if (isString(proxy.path)) {
                resultMapStrings.push(proxy.path || '');
            }

            return resultMapStrings;
        }, []);
    }

    return [];
}

function mergeBabelConfig(baseConfig: TransformOptions, mergeConfig: TransformOptions) {
    const basePresets = baseConfig.presets || [];
    const mergePresets = mergeConfig.presets || [];
    const basePlugins = baseConfig.plugins || [];
    const mergePlugins = mergeConfig.plugins || [];

    return {
        ...baseConfig,
        presets: [...basePresets, ...mergePresets],
        plugins: [...basePlugins, ...mergePlugins]
    }
}

export default {
    chalk,
    loggerPrefix,
    logger,
    success,
    warning,
    error,
    noop,
    getEnv,
    isDev,
    isProduction,
    isFunction,
    isObject,
    isString,
    requireModule,
    getWebpackProxyPath,
    mergeBabelConfig
};

==> react-build-cli-0.1.4.tgz: package/src/utils.ts <==
import chalk from 'chalk';
import {Configuration as webpackDevServerConfiguration} from 'webpack-dev-server';
import webpack from 'webpack';

interface Configuration extends webpack.Configuration {
    devServer?: webpackDevServerConfiguration;
}

function noop() {
    return null;
}

function getEnv(){
    return process.env.NODE_ENV as 'development' | 'production' ;
}

function isDev() {
    return process.env.NODE_ENV === 'development';
}

function isProduction() {
    return process.env.NODE_ENV === 'production';
}

function isFunction(func: any): boolean {
    return Object.prototype.toString.call(func) === '[object Function]';
}

function isObject(obj: any): boolean {
    return Object.prototype.toString.call(obj) === '[object Object]';
}

function isString(str: any) {
    return Object.prototype.toString.call(str) === '[object String]';
}

function loggerPrefix(message: string, options?: {name?: string}) {
    const {name = 'info'} = options || {};
    console.log(`${chalk.blue(`react-build-cli:${name}`)} ${message}`);
}

function success(info: string) {
    loggerPrefix(`${chalk.green('✔')} ${chalk.blue(info)}`);
}

function logger(info: string) {
    loggerPrefix(chalk.green(info));
}

function warning(info: string) {
    loggerPrefix(chalk.yellow(info));
}

function error(info: string) {
    loggerPrefix(chalk.red(info));
}

function requireModule(modulePath: string) {
    return require(modulePath).default || require(modulePath);
}

function getWebpackProxyPath(webpackConfig: Configuration): string[] {
    if (webpackConfig && webpackConfig.devServer && isObject(webpackConfig.devServer.proxy)) {
        const proxyPath: string[] = Object.keys(webpackConfig.devServer?.proxy || {});
        const resultMapStrings: string[] = [];
        
        proxyPath.forEach(key => {
            const proxy = ((webpackConfig.devServer?.proxy || {}) as any)[key];
            if (isObject(proxy)) {
                resultMapStrings.push(`${key} => ${proxy.target}`);
            }
            else if (isString(proxy)) {
                resultMapStrings.push(`${key} => ${proxy}`);
            }
        });

        return resultMapStrings;
    }

    if (webpackConfig && webpackConfig.devServer && Array.isArray(webpackConfig.devServer.proxy)) {
        return (webpackConfig.devServer?.proxy || []).reduce((resultMapStrings: string[], proxy) => {
            if(Array.isArray(proxy.path)) {
                resultMapStrings = [...resultMapStrings, ...proxy.path];
            }
            else if (isString(proxy.path)) {
                resultMapStrings.push(proxy.path || '');
            }

            return resultMapStrings;
        }, []);
    }

    return [];
}

function mergeBabelConfig(baseConfig: any, mergeConfig: any) {
    const basePresets = baseConfig.presets || [];
    const mergePresets = mergeConfig.presets || [];
    const basePlugins = baseConfig.plugins || [];
    const mergePlugins = mergeConfig.plugins || [];

    return {
        ...baseConfig,
        presets: [...basePresets, ...mergePresets],
        plugins: [...basePlugins, ...mergePlugins]
    }
}

export default {
    chalk,
    loggerPrefix,
    logger,
    success,
    warning,
    error,
    noop,
    getEnv,
    isDev,
    isProduction,
    isFunction,
    isObject,
    isString,
    requireModule,
    getWebpackProxyPath,
    mergeBabelConfig
};
